@@ -1,6 +1,13 @@
 import requests, zipfile,sys,os,tarfile
 zip_file_url = "https://www.s79.ir/tmp/test.tar.gz"
 
+
+print("===================================")
+print("====== Flask project manager ======")
+print("===================================")
+print("Initializing new flask project....")
+print("Downloading requirements ....")
+
 def main():
     r = requests.get(zip_file_url, stream=True)
     with open('tmp.tgz', 'wb') as file:
